==> packageinstaller-pkglist-libre_0.2.1.tar.xz: packageinstaller-pkglist-libre/imagemagick.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
ImageMagick
</name>

<description>
   <am>a software suite to create, edit, and compose bitmap images</am>
   <ar>a software suite to create, edit, and compose bitmap images</ar>
   <be>a software suite to create, edit, and compose bitmap images</be>
   <bg>a software suite to create, edit, and compose bitmap images</bg>
   <bn>a software suite to create, edit, and compose bitmap images</bn>
   <ca>Programari per crear, editar i compondre imatges de mapa de bits</ca>
   <cs>a software suite to create, edit, and compose bitmap images</cs>
   <da>en softwarepake til at oprette, redigere og komponere bitmap-billeder</da>
   <de>Eine Software-Suite zum Erstellen, Bearbeiten und Komponieren von Bitmap-Bildern</de>
   <el>Σουίτα λογισμικού για τη δημιουργία, επεξεργασία και σύνθεση εικόνων bitmap</el>
   <en>a software suite to create, edit, and compose bitmap images</en>
   <es_ES>Un paquete de software para crear, editar y componer imágenes de mapa de bits.</es_ES>
   <es>Un paquete de software para crear, editar y componer imágenes de mapa de bits.</es>
   <et>a software suite to create, edit, and compose bitmap images</et>
   <eu>a software suite to create, edit, and compose bitmap images</eu>
   <fa>a software suite to create, edit, and compose bitmap images</fa>
   <fil_PH>a software suite to create, edit, and compose bitmap images</fil_PH>
   <fi>ohjelma jonka avulla luot, muokkaat ja tuotat bitmap-muotoisia kuvia</fi>
   <fr_BE>Une suite logicielle pour créer et modifier des images bitmap</fr_BE>
   <fr>Une suite logicielle pour créer et modifier des images bitmap</fr>
   <gl_ES>Conxunto de programas para crear, editar e compoñer imaxes bitmap</gl_ES>
   <gu>a software suite to create, edit, and compose bitmap images</gu>
   <he_IL>a software suite to create, edit, and compose bitmap images</he_IL>
   <hi>बिटमैप चित्र सृजन, संपादन व संयोजन हेतु सॉफ्टवेयर संग्रह</hi>
   <hr>a software suite to create, edit, and compose bitmap images</hr>
   <hu>a software suite to create, edit, and compose bitmap images</hu>
   <id>a software suite to create, edit, and compose bitmap images</id>
   <is>a software suite to create, edit, and compose bitmap images</is>
   <it>una suite di programmi per creare, modificare e comporre immagini bitmap</it>
   <ja>ビットマップ画像の作成・編集・合成を行うソフトウェアスイート</ja>
   <kk>a software suite to create, edit, and compose bitmap images</kk>
   <ko>a software suite to create, edit, and compose bitmap images</ko>
   <lt>a software suite to create, edit, and compose bitmap images</lt>
   <mk>a software suite to create, edit, and compose bitmap images</mk>
   <mr>a software suite to create, edit, and compose bitmap images</mr>
   <nb_NO>a software suite to create, edit, and compose bitmap images</nb_NO>
   <nb>programpakke for å lage, redigere og sette sammen punktgrafikk</nb>
   <nl_BE>a software suite to create, edit, and compose bitmap images</nl_BE>
   <nl>een softwaresuite voor het maken, bewerken en samenstellen van bitmapafbeeldingen</nl>
   <pl>pakiet oprogramowania do tworzenia, edycji i komponowania grafiki bitmapowej (rastrowej)</pl>
   <pt_BR>Conjunto de programas para criar, editar e compor imagens bitmap</pt_BR>
   <pt>Conjunto de programas para criar, editar, e compôr imagens bitmap</pt>
   <ro>a software suite to create, edit, and compose bitmap images</ro>
   <ru>Набор утилит для чтения и редактирования множества графических форматов</ru>
   <sk>a software suite to create, edit, and compose bitmap images</sk>
   <sl>Programski paket za ustvarjanje, urejanje in snovanje bitnih slik</sl>
   <sq>Një suitë software-i për krijim, përpunim dhe hartim figurash bitmap</sq>
   <sr>a software suite to create, edit, and compose bitmap images</sr>
   <sv>en mjukvarusvit för att skapa, redigera, och komponera bitmapbilder</sv>
   <th>a software suite to create, edit, and compose bitmap images</th>
   <tr>bitmap resimler oluşturmak ve düzenlemek için bir yazılım takımı</tr>
   <uk>набір програм для створення, редагування та перетворення растрових зображень</uk>
   <vi>a software suite to create, edit, and compose bitmap images</vi>
   <zh_CN>a software suite to create, edit, and compose bitmap images</zh_CN>
   <zh_HK>a software suite to create, edit, and compose bitmap images</zh_HK>
   <zh_TW>a software suite to create, edit, and compose bitmap images</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
imagemagick
imagemagick-doc
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
imagemagick
imagemagick-doc
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.2.2.tar.xz: packageinstaller-pkglist-libre/imagemagick.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
ImageMagick
</name>

<description>
   <am>a software suite to create, edit, and compose bitmap images</am>
   <ar>a software suite to create, edit, and compose bitmap images</ar>
   <be>a software suite to create, edit, and compose bitmap images</be>
   <bg>a software suite to create, edit, and compose bitmap images</bg>
   <bn>a software suite to create, edit, and compose bitmap images</bn>
   <ca>Programari per crear, editar i compondre imatges de mapa de bits</ca>
   <cs>a software suite to create, edit, and compose bitmap images</cs>
   <da>en softwarepake til at oprette, redigere og komponere bitmap-billeder</da>
   <de>Eine Software-Suite zum Erstellen, Bearbeiten und Komponieren von Bitmap-Bildern</de>
   <el>Σουίτα λογισμικού για τη δημιουργία, επεξεργασία και σύνθεση εικόνων bitmap</el>
   <en>a software suite to create, edit, and compose bitmap images</en>
   <es_ES>Un paquete de software para crear, editar y componer imágenes de mapa de bits.</es_ES>
   <es>Un paquete de software para crear, editar y componer imágenes de mapa de bits.</es>
   <et>a software suite to create, edit, and compose bitmap images</et>
   <eu>a software suite to create, edit, and compose bitmap images</eu>
   <fa>a software suite to create, edit, and compose bitmap images</fa>
   <fil_PH>a software suite to create, edit, and compose bitmap images</fil_PH>
   <fi>ohjelma jonka avulla luot, muokkaat ja tuotat bitmap-muotoisia kuvia</fi>
   <fr_BE>Une suite logicielle pour créer et modifier des images bitmap</fr_BE>
   <fr>Une suite logicielle pour créer et modifier des images bitmap</fr>
   <gl_ES>Conxunto de programas para crear, editar e compoñer imaxes bitmap</gl_ES>
   <gu>a software suite to create, edit, and compose bitmap images</gu>
   <he_IL>a software suite to create, edit, and compose bitmap images</he_IL>
   <hi>बिटमैप चित्र सृजन, संपादन व संयोजन हेतु सॉफ्टवेयर संग्रह</hi>
   <hr>a software suite to create, edit, and compose bitmap images</hr>
   <hu>a software suite to create, edit, and compose bitmap images</hu>
   <id>a software suite to create, edit, and compose bitmap images</id>
   <is>a software suite to create, edit, and compose bitmap images</is>
   <it>una suite di programmi per creare, modificare e comporre immagini bitmap</it>
   <ja>ビットマップ画像の作成・編集・合成を行うソフトウェアスイート</ja>
   <kk>a software suite to create, edit, and compose bitmap images</kk>
   <ko>a software suite to create, edit, and compose bitmap images</ko>
   <ku>a software suite to create, edit, and compose bitmap images</ku>
   <lt>a software suite to create, edit, and compose bitmap images</lt>
   <mk>a software suite to create, edit, and compose bitmap images</mk>
   <mr>a software suite to create, edit, and compose bitmap images</mr>
   <nb_NO>a software suite to create, edit, and compose bitmap images</nb_NO>
   <nb>programpakke for å lage, redigere og sette sammen punktgrafikk</nb>
   <nl_BE>a software suite to create, edit, and compose bitmap images</nl_BE>
   <nl>een softwaresuite voor het maken, bewerken en samenstellen van bitmapafbeeldingen</nl>
   <or>a software suite to create, edit, and compose bitmap images</or>
   <pl>pakiet oprogramowania do tworzenia, edycji i komponowania grafiki bitmapowej (rastrowej)</pl>
   <pt_BR>Conjunto de programas para criar, editar e compor imagens bitmap</pt_BR>
   <pt>Conjunto de programas para criar, editar, e compôr imagens bitmap</pt>
   <ro>a software suite to create, edit, and compose bitmap images</ro>
   <ru>Набор утилит для чтения и редактирования множества графических форматов</ru>
   <sk>a software suite to create, edit, and compose bitmap images</sk>
   <sl>Programski paket za ustvarjanje, urejanje in snovanje bitnih slik</sl>
   <so>a software suite to create, edit, and compose bitmap images</so>
   <sq>Një suitë software-i për krijim, përpunim dhe hartim figurash bitmap</sq>
   <sr>a software suite to create, edit, and compose bitmap images</sr>
   <sv>en mjukvarusvit för att skapa, redigera, och komponera bitmapbilder</sv>
   <th>a software suite to create, edit, and compose bitmap images</th>
   <tr>bitmap resimler oluşturmak ve düzenlemek için bir yazılım takımı</tr>
   <uk>набір програм для створення, редагування та перетворення растрових зображень</uk>
   <vi>a software suite to create, edit, and compose bitmap images</vi>
   <zh_CN>a software suite to create, edit, and compose bitmap images</zh_CN>
   <zh_HK>a software suite to create, edit, and compose bitmap images</zh_HK>
   <zh_TW>a software suite to create, edit, and compose bitmap images</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
imagemagick
imagemagick-doc
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
imagemagick
imagemagick-doc
</uninstall_package_names>
</app>
